==> icon_forest-1.0.2.tar.gz: lib/bpmn.dart <==
import 'package:flutter/material.dart';

class _Bpmn extends IconData {
  const _Bpmn(int codePoint)
      : super(codePoint, fontFamily: 'bpmn', fontPackage: 'icon_forest');
}

class Bpmn {
  static const IconData ad_hoc_marker = _Bpmn(0xe800);
  static const IconData bpmn_io = _Bpmn(0xe801);
  static const IconData business_rule_task = _Bpmn(0xe802);
  static const IconData business_rule = _Bpmn(0xe803);
  static const IconData call_activity = _Bpmn(0xe804);
  static const IconData compensation_marker = _Bpmn(0xe805);
  static const IconData conditional_flow = _Bpmn(0xe806);
  static const IconData connection_multi = _Bpmn(0xe807);
  static const IconData connection = _Bpmn(0xe808);
  static const IconData data_input = _Bpmn(0xe809);
  static const IconData data_object = _Bpmn(0xe80a);
  static const IconData data_output = _Bpmn(0xe80b);
  static const IconData data_store = _Bpmn(0xe80c);
  static const IconData default_flow = _Bpmn(0xe80d);
  static const IconData end_event_cancel = _Bpmn(0xe80e);
  static const IconData end_event_compensation = _Bpmn(0xe80f);
  static const IconData end_event_error = _Bpmn(0xe810);
  static const IconData end_event_escalation = _Bpmn(0xe811);
  static const IconData end_event_link = _Bpmn(0xe812);
  static const IconData end_event_message = _Bpmn(0xe813);
  static const IconData end_event_multiple = _Bpmn(0xe814);
  static const IconData end_event_none = _Bpmn(0xe815);
  static const IconData end_event_signal = _Bpmn(0xe816);
  static const IconData end_event_terminate = _Bpmn(0xe817);
  static const IconData event_subprocess_expanded = _Bpmn(0xe818);
  static const IconData gateway_complex = _Bpmn(0xe819);
  static const IconData gateway_eventbased = _Bpmn(0xe81a);
  static const IconData gateway_none = _Bpmn(0xe81b);
  static const IconData gateway_or = _Bpmn(0xe81c);
  static const IconData gateway_parallel = _Bpmn(0xe81d);
  static const IconData gateway_xor = _Bpmn(0xe81e);
  static const IconData group = _Bpmn(0xe81f);
  static const IconData hand_tool = _Bpmn(0xe820);
  static const IconData intermediate_event_catch_cancel = _Bpmn(0xe821);
  static const IconData intermediate_event_catch_compensation = _Bpmn(0xe822);
  static const IconData intermediate_event_catch_condition = _Bpmn(0xe823);
  static const IconData intermediate_event_catch_error = _Bpmn(0xe824);
  static const IconData intermediate_event_catch_escalation = _Bpmn(0xe825);
  static const IconData intermediate_event_catch_link = _Bpmn(0xe826);
  static const IconData intermediate_event_catch_message = _Bpmn(0xe827);
  static const IconData intermediate_event_catch_multiple = _Bpmn(0xe828);
  static const IconData intermediate_event_catch_non_interrupting_condition =
      _Bpmn(0xe829);
  static const IconData intermediate_event_catch_non_interrupting_escalation =
      _Bpmn(0xe82a);
  static const IconData intermediate_event_catch_non_interrupting_message =
      _Bpmn(0xe82b);
  static const IconData intermediate_event_catch_non_interrupting_multiple =
      _Bpmn(0xe82c);
  static const IconData
      intermediate_event_catch_non_interrupting_parallel_multiple =
      _Bpmn(0xe82d);
  static const IconData intermediate_event_catch_non_interrupting_signal =
      _Bpmn(0xe82e);
  static const IconData intermediate_event_catch_non_interrupting_timer =
      _Bpmn(0xe82f);
  static const IconData intermediate_event_catch_parallel_multiple =
      _Bpmn(0xe830);
  static const IconData intermediate_event_catch_signal = _Bpmn(0xe831);
  static const IconData intermediate_event_catch_timer = _Bpmn(0xe832);
  static const IconData intermediate_event_none = _Bpmn(0xe833);
  static const IconData intermediate_event_throw_compensation = _Bpmn(0xe834);
  static const IconData intermediate_event_throw_escalation = _Bpmn(0xe835);
  static const IconData intermediate_event_throw_link = _Bpmn(0xe836);
  static const IconData intermediate_event_throw_message = _Bpmn(0xe837);
  static const IconData intermediate_event_throw_multiple = _Bpmn(0xe838);
  static const IconData intermediate_event_throw_signal = _Bpmn(0xe839);
  static const IconData lane_divide_three = _Bpmn(0xe83a);
  static const IconData lane_divide_two = _Bpmn(0xe83b);
  static const IconData lane_insert_above = _Bpmn(0xe83c);
  static const IconData lane_insert_below = _Bpmn(0xe83d);
  static const IconData lane = _Bpmn(0xe83e);
  static const IconData lasso_tool = _Bpmn(0xe83f);
  static const IconData loop_marker = _Bpmn(0xe840);
  static const IconData manual_task = _Bpmn(0xe841);
  static const IconData manual = _Bpmn(0xe842);
  static const IconData parallel_mi_marker = _Bpmn(0xe843);
  static const IconData participant = _Bpmn(0xe844);
  static const IconData receive_task = _Bpmn(0xe845);
  static const IconData receive = _Bpmn(0xe846);
  static const IconData screw_wrench = _Bpmn(0xe847);
  static const IconData script_task = _Bpmn(0xe848);
  static const IconData script = _Bpmn(0xe849);
  static const IconData send_task = _Bpmn(0xe84a);
  static const IconData send = _Bpmn(0xe84b);
  static const IconData sequential_mi_marker = _Bpmn(0xe84c);
  static const IconData service_task = _Bpmn(0xe84d);
  static const IconData service = _Bpmn(0xe84e);
  static const IconData space_tool = _Bpmn(0xe84f);
  static const IconData start_event_compensation = _Bpmn(0xe850);
  static const IconData start_event_condition = _Bpmn(0xe851);
  static const IconData start_event_error = _Bpmn(0xe852);
  static const IconData start_event_escalation = _Bpmn(0xe853);
  static const IconData start_event_message = _Bpmn(0xe854);
  static const IconData start_event_multiple = _Bpmn(0xe855);
  static const IconData start_event_non_interrupting_condition = _Bpmn(0xe856);
  static const IconData start_event_non_interrupting_escalation = _Bpmn(0xe857);
  static const IconData start_event_non_interrupting_message = _Bpmn(0xe858);
  static const IconData start_event_non_interrupting_multiple = _Bpmn(0xe859);
  static const IconData start_event_non_interrupting_parallel_multiple =
      _Bpmn(0xe85a);
  static const IconData start_event_non_interrupting_signal = _Bpmn(0xe85b);
  static const IconData start_event_non_interrupting_timer = _Bpmn(0xe85c);
  static const IconData start_event_none = _Bpmn(0xe85d);
  static const IconData start_event_parallel_multiple = _Bpmn(0xe85e);
  static const IconData start_event_signal = _Bpmn(0xe85f);
  static const IconData start_event_timer = _Bpmn(0xe860);
  static const IconData sub_process_marker = _Bpmn(0xe861);
  static const IconData subprocess_collapsed = _Bpmn(0xe862);
  static const IconData subprocess_expanded = _Bpmn(0xe863);
  static const IconData task_none = _Bpmn(0xe864);
  static const IconData task = _Bpmn(0xe865);
  static const IconData text_annotation = _Bpmn(0xe866);
  static const IconData transaction = _Bpmn(0xe867);
  static const IconData trash = _Bpmn(0xe868);
  static const IconData user_task = _Bpmn(0xe869);
  static const IconData user = _Bpmn(0xe86a);
}

==> icon_forest-1.0.9.tar.gz: lib/bpmn.dart <==
import 'package:flutter/material.dart';

/// bpmn icon pack (106 icons)
class _Bpmn extends IconData {
  const _Bpmn(int codePoint) : super(codePoint, fontFamily: 'bpmn', fontPackage: 'icon_forest');
}

/// constants link to font code point
class Bpmn {
  static const IconData ad_hoc_marker = _Bpmn(0xe800);
  static const IconData bpmn_io = _Bpmn(0xe801);
  static const IconData business_rule_task = _Bpmn(0xe802);
  static const IconData business_rule = _Bpmn(0xe803);
  static const IconData call_activity = _Bpmn(0xe804);
  static const IconData compensation_marker = _Bpmn(0xe805);
  static const IconData conditional_flow = _Bpmn(0xe806);
  static const IconData connection_multi = _Bpmn(0xe807);
  static const IconData connection = _Bpmn(0xe808);
  static const IconData data_input = _Bpmn(0xe809);
  static const IconData data_object = _Bpmn(0xe80a);
  static const IconData data_output = _Bpmn(0xe80b);
  static const IconData data_store = _Bpmn(0xe80c);
  static const IconData default_flow = _Bpmn(0xe80d);
  static const IconData end_event_cancel = _Bpmn(0xe80e);
  static const IconData end_event_compensation = _Bpmn(0xe80f);
  static const IconData end_event_error = _Bpmn(0xe810);
  static const IconData end_event_escalation = _Bpmn(0xe811);
  static const IconData end_event_link = _Bpmn(0xe812);
  static const IconData end_event_message = _Bpmn(0xe813);
  static const IconData end_event_multiple = _Bpmn(0xe814);
  static const IconData end_event_none = _Bpmn(0xe815);
  static const IconData end_event_signal = _Bpmn(0xe816);
  static const IconData end_event_terminate = _Bpmn(0xe817);
  static const IconData event_subprocess_expanded = _Bpmn(0xe818);
  static const IconData gateway_complex = _Bpmn(0xe819);
  static const IconData gateway_eventbased = _Bpmn(0xe81a);
  static const IconData gateway_none = _Bpmn(0xe81b);
  static const IconData gateway_or = _Bpmn(0xe81c);
  static const IconData gateway_parallel = _Bpmn(0xe81d);
  static const IconData gateway_xor = _Bpmn(0xe81e);
  static const IconData group = _Bpmn(0xe81f);
  static const IconData hand_tool = _Bpmn(0xe820);
  static const IconData intermediate_event_catch_cancel = _Bpmn(0xe821);
  static const IconData intermediate_event_catch_compensation = _Bpmn(0xe822);
  static const IconData intermediate_event_catch_condition = _Bpmn(0xe823);
  static const IconData intermediate_event_catch_error = _Bpmn(0xe824);
  static const IconData intermediate_event_catch_escalation = _Bpmn(0xe825);
  static const IconData intermediate_event_catch_link = _Bpmn(0xe826);
  static const IconData intermediate_event_catch_message = _Bpmn(0xe827);
  static const IconData intermediate_event_catch_multiple = _Bpmn(0xe828);
  static const IconData intermediate_event_catch_non_interrupting_condition = _Bpmn(0xe829);
  static const IconData intermediate_event_catch_non_interrupting_escalation = _Bpmn(0xe82a);
  static const IconData intermediate_event_catch_non_interrupting_message = _Bpmn(0xe82b);
  static const IconData intermediate_event_catch_non_interrupting_multiple = _Bpmn(0xe82c);
  static const IconData intermediate_event_catch_non_interrupting_parallel_multiple = _Bpmn(0xe82d);
  static const IconData intermediate_event_catch_non_interrupting_signal = _Bpmn(0xe82e);
  static const IconData intermediate_event_catch_non_interrupting_timer = _Bpmn(0xe82f);
  static const IconData intermediate_event_catch_parallel_multiple = _Bpmn(0xe830);
  static const IconData intermediate_event_catch_signal = _Bpmn(0xe831);
  static const IconData intermediate_event_catch_timer = _Bpmn(0xe832);
  static const IconData intermediate_event_none = _Bpmn(0xe833);
  static const IconData intermediate_event_throw_compensation = _Bpmn(0xe834);
  static const IconData intermediate_event_throw_escalation = _Bpmn(0xe835);
  static const IconData intermediate_event_throw_link = _Bpmn(0xe836);
  static const IconData intermediate_event_throw_message = _Bpmn(0xe837);
  static const IconData intermediate_event_throw_multiple = _Bpmn(0xe838);
  static const IconData intermediate_event_throw_signal = _Bpmn(0xe839);
  static const IconData lane_divide_three = _Bpmn(0xe83a);
  static const IconData lane_divide_two = _Bpmn(0xe83b);
  static const IconData lane_insert_above = _Bpmn(0xe83c);
  static const IconData lane_insert_below = _Bpmn(0xe83d);
  static const IconData lane = _Bpmn(0xe83e);
  static const IconData lasso_tool = _Bpmn(0xe83f);
  static const IconData loop_marker = _Bpmn(0xe840);
  static const IconData manual_task = _Bpmn(0xe841);
  static const IconData manual = _Bpmn(0xe842);
  static const IconData parallel_mi_marker = _Bpmn(0xe843);
  static const IconData participant = _Bpmn(0xe844);
  static const IconData receive_task = _Bpmn(0xe845);
  static const IconData receive = _Bpmn(0xe846);
  static const IconData screw_wrench = _Bpmn(0xe847);
  static const IconData script_task = _Bpmn(0xe848);
  static const IconData script = _Bpmn(0xe849);
  static const IconData send_task = _Bpmn(0xe84a);
  static const IconData send = _Bpmn(0xe84b);
  static const IconData sequential_mi_marker = _Bpmn(0xe84c);
  static const IconData service_task = _Bpmn(0xe84d);
  static const IconData service = _Bpmn(0xe84e);
  static const IconData space_tool = _Bpmn(0xe84f);
  static const IconData start_event_compensation = _Bpmn(0xe850);
  static const IconData start_event_condition = _Bpmn(0xe851);
  static const IconData start_event_error = _Bpmn(0xe852);
  static const IconData start_event_escalation = _Bpmn(0xe853);
  static const IconData start_event_message = _Bpmn(0xe854);
  static const IconData start_event_multiple = _Bpmn(0xe855);
  static const IconData start_event_non_interrupting_condition = _Bpmn(0xe856);
  static const IconData start_event_non_interrupting_escalation = _Bpmn(0xe857);
  static const IconData start_event_non_interrupting_message = _Bpmn(0xe858);
  static const IconData start_event_non_interrupting_multiple = _Bpmn(0xe859);
  static const IconData start_event_non_interrupting_parallel_multiple = _Bpmn(0xe85a);
  static const IconData start_event_non_interrupting_signal = _Bpmn(0xe85b);
  static const IconData start_event_non_interrupting_timer = _Bpmn(0xe85c);
  static const IconData start_event_none = _Bpmn(0xe85d);
  static const IconData start_event_parallel_multiple = _Bpmn(0xe85e);
  static const IconData start_event_signal = _Bpmn(0xe85f);
  static const IconData start_event_timer = _Bpmn(0xe860);
  static const IconData sub_process_marker = _Bpmn(0xe861);
  static const IconData subprocess_collapsed = _Bpmn(0xe862);
  static const IconData subprocess_expanded = _Bpmn(0xe863);
  static const IconData task_none = _Bpmn(0xe864);
  static const IconData task = _Bpmn(0xe865);
  static const IconData text_annotation = _Bpmn(0xe866);
  static const IconData transaction = _Bpmn(0xe867);
  static const IconData trash = _Bpmn(0xe868);
  static const IconData user_task = _Bpmn(0xe869);
  static const IconData user = _Bpmn(0xe86a);
}
